@@ -38,7 +38,6 @@
  */
 
 
-#include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 #include <ctype.h>
@@ -59,23 +58,32 @@ using namespace hy_global;
 // AVL Lists
 //______________________________________________________________
 
-_AVLList::_AVLList (_SimpleList* d)
-{
+_AVLList::_AVLList (_SimpleList* d) {
     dataList = d;
     root     = -1;
 }
 
+_AVLList::_AVLList (_AVLList const &) {
+    HandleApplicationError("Called _AVLList:: copy constructor  method stub that is not implemented");
+}
+
 //______________________________________________________________
 
 BaseRef _AVLList::makeDynamic (void) const {
     HandleApplicationError("Called _AVLList::makeDynamic:  method stub that is not implemented");
+    return nil;
 }
 
 //______________________________________________________________
 
 void _AVLList::Duplicate (BaseRefConst) {
     HandleApplicationError("Called _AVLList::Duplicate:  method stub that is not implemented");
-    
+}
+
+//______________________________________________________________
+
+void _AVLList::operator = (_AVLList const & rhs) {
+    HandleApplicationError("Called _AVLList::operator = :  method stub that is not implemented");
 }
 
 //______________________________________________________________
@@ -271,8 +279,7 @@ bool  _AVLList::IsValidIndex(long index) const {
 
 //______________________________________________________________
 
-long  _AVLList::GetByIndex (const long theIndex)
-{
+long  _AVLList::GetByIndex (const long theIndex) {
     if (theIndex == 0) {
         return First();
     }
@@ -304,8 +311,11 @@ long  _AVLList::GetByIndex (const long theIndex)
 //______________________________________________________________
 
 void  _AVLList::ReorderList (_SimpleList *s) {
-    _SimpleList reorderMe ((unsigned long)(dataList->lLength-emptySlots.lLength+1)),
-                nodeStack ((unsigned long)64);
+    
+    unsigned long item_count = (dataList->lLength-emptySlots.lLength+1);
+    
+    _SimpleList reorderMe (item_count),
+                nodeStack (64UL, (long*)alloca (64*sizeof (unsigned long)));
 
     long        curNode = root;
 
@@ -320,9 +330,8 @@ void  _AVLList::ReorderList (_SimpleList *s) {
             if (s) {
                 (*s) << curNode;
             }
+            
             reorderMe.InsertElement (((BaseRef*)dataList->list_data)[curNode],-1,false,false);
-
-            //TODO:???
             curNode = rightChild.list_data[curNode];
             nodeStack.Delete (h, false);
 
@@ -332,14 +341,6 @@ void  _AVLList::ReorderList (_SimpleList *s) {
     }
 
     reorderMe.TrimMemory ();
-    
-
-    /*long* t             = dataList->list_data;
-    dataList->list_data     = reorderMe.list_data;
-    dataList->lLength   = reorderMe.lLength;
-    dataList->laLength  = reorderMe.laLength;
-    reorderMe.list_data     = t;*/
-    
     *dataList = reorderMe;
 }
 
@@ -467,7 +468,6 @@ const _List  _AVLList::Keys (void) const {
       
       cn = Traverser (hist,ls,root);
       
-      bool first = true;
       while (cn>=0) {
         keys << Retrieve (cn);
         cn = Traverser (hist,ls);
@@ -571,6 +571,7 @@ long  _AVLList::Insert (BaseRef b, long xtra,bool cp,bool clear) {
                 if (cp == false && clear) {
                     DeleteObject (b);
                 }
+                // already exists, return the node it mapped to
                 return -p-1;
             }
             if (balanceFactor.list_data[p] != 0) {
@@ -699,10 +700,6 @@ long  _AVLList::Insert (BaseRef b, long xtra,bool cp,bool clear) {
         return p;
     }
 
-    /*dataList->InsertElement (b,-1,false,false);
-    leftChild  << -1;
-    rightChild << -1;
-    balanceFactor << 0;*/
     root =InsertData (b, xtra,cp);
 
     return 0;
